@@ -1,4 +1,3 @@
-# -*- CPERL -*-
 # /=====================================================================\ #
 # |  LaTeXML                                                            | #
 # | Core Module for TeX conversion                                      | #
@@ -54,6 +53,7 @@ sub new {
         @{ $options{graphicspaths} || [] }], 'global');
   $state->assignValue(INCLUDE_STYLES => $options{includeStyles} || 0, 'global');
   $state->assignValue(PERL_INPUT_ENCODING => $options{inputencoding}) if $options{inputencoding};
+  $state->assignValue(NOMATHPARSE => $options{nomathparse} || 0, 'global');
   return bless { state => $state,
     nomathparse => $options{nomathparse} || 0,
     preload => $options{preload},
@@ -205,7 +205,8 @@ sub convertDocument {
         else {
           $preload =~ s/\.sty$//;
           $document->insertPI('latexml', package => $preload, ($options ? (options => $options) : ())); } }
-      $document->absorb($digested);
+      { no warnings 'recursion';
+        $document->absorb($digested); }
       NoteEnd("Building");
 
       if (my $rules = $state->lookupValue('DOCUMENT_REWRITE_RULES')) {
@@ -225,10 +226,12 @@ sub withState {
   my ($self, $closure) = @_;
   local $STATE = $$self{state};
   # And, set fancy error handler for ANY die!
-  # Could be useful to distill the more common messages so they provide useful build statistics?
-  local $SIG{__DIE__} = sub { LaTeXML::Common::Error::perl_die_handler(@_); };
-  local $SIG{INT} = sub { LaTeXML::Common::Error::Fatal('perl', 'interrupt', undef, "LaTeXML was interrupted", @_); };
-  local $SIG{__WARN__} = sub { LaTeXML::Common::Error::perl_warn_handler(@_); };
+  local $SIG{__DIE__}  = \&LaTeXML::Common::Error::perl_die_handler;
+  local $SIG{INT}      = \&LaTeXML::Common::Error::perl_interrupt_handler;
+  local $SIG{__WARN__} = \&LaTeXML::Common::Error::perl_warn_handler;
+  local $SIG{'ALRM'}   = \&LaTeXML::Common::Error::perl_timeout_handler;
+  local $SIG{'TERM'}   = \&LaTeXML::Common::Error::perl_terminate_handler;
+
   local $LaTeXML::DUAL_BRANCH = '';
 
   return &$closure($STATE); }
@@ -240,6 +243,7 @@ sub initializeState {
   my $gullet  = $stomach->getGullet;
   $stomach->initialize;
   my $paths = $state->lookupValue('SEARCHPATHS');
+  $state->assignValue('InitialPreloads' => 1, 'global');
   foreach my $preload (@files) {
     my ($options, $type);
     $options = $1 if $preload =~ s/^\[([^\]]*)\]//;
@@ -259,6 +263,7 @@ sub initializeState {
     LaTeXML::Package::InputDefinitions($preload, type => $type,
       handleoptions => $handleoptions, options => $options);
   }
+  $state->assignValue('InitialPreloads' => undef, 'global');
   return; }
 
 sub writeDOM {
@@ -276,7 +281,7 @@ sub writeDOM {
 
 __END__
 
-=pod 
+=pod
 
 =head1 NAME
 
@@ -298,11 +303,11 @@ But also see the convenient command line script L<latexml> which suffices for mo
 
 =item C<< my $latexml = LaTeXML::Core->new(%options); >>
 
-Creates a new LaTeXML object for transforming TeX files into XML. 
+Creates a new LaTeXML object for transforming TeX files into XML.
 
  verbosity  : Controls verbosity; higher is more verbose,
               smaller is quieter. 0 is the default.
- strict     : If true, undefined control sequences and 
+ strict     : If true, undefined control sequences and
               invalid document constructs give fatal
               errors, instead of warnings.
  includeComments : If false, comments will be excluded
@@ -328,7 +333,7 @@ B<OBSOLETE> Use C<$latexml->convertFile("literal:$string");> instead.
 
 =item C<< $latexml->writeDOM($doc,$name); >>
 
-Writes the XML document to $name.xml. 
+Writes the XML document to $name.xml.
 
 =item C<< $box = $latexml->digestFile($file); >>
 
@@ -349,7 +354,7 @@ returning the L<XML::LibXML::Document>.
 
 In the simplest case, LaTeXML will understand your source file and convert it
 automatically.  With more complicated (realistic) documents, you will likely
-need to make document specific declarations for it to understand local macros, 
+need to make document specific declarations for it to understand local macros,
 your mathematical notations, and so forth.  Before processing a file
 I<doc.tex>, LaTeXML reads the file I<doc.latexml>, if present.
 Likewise, the LaTeXML implementation of a TeX style file, say
@@ -377,7 +382,7 @@ variables, definitions, etc.
 
 =item  L<LaTeXML::Core::Token>, L<LaTeXML::Core::Mouth> and L<LaTeXML::Core::Gullet>
 
-deal with tokens, tokenization of strings and files, and 
+deal with tokens, tokenization of strings and files, and
 basic TeX sequences such as arguments, dimensions and so forth.
 
 =item L<LaTeXML::Core::Box> and  L<LaTeXML::Core::Stomach>
